
#include "LPC17xx.h"
#include "DoxyTest.h"


/**
 *
 *  \file     DoxyTest.c
 *  \mainpage DoxyTest
 *
 *  Dies ist eine einfache Testapplikation in C, um die Konfiguration
 *  des Entwicklungssystems LPCXpresso zu testen und die Funktionalität
 *  von Doxygen zu demonstrieren.<BR><BR>
 *  Das Programm läßt die rote LED auf dem Controllerboard blinken.
 *
 *  <HR>
 *
 *  \section sec1 Einleitung
 *  Hier folgt eine kurze Einleitung...
 *
 *  \section sec2 Unterprogramme
 *
 *  In diesem Abschnitt erfolgt die Beschreibung der einzelnen
 *  Unterprogramme
 *
 *  \subsection sec2_1 Allgemeines, Initialisierung
 *
 *  Hier werden die C-Funktionen beschrieben, die der Initialisierung
 *  der Hardware sowie weiteren, einmalig auszuführenden Aufgaben
 *  dienen ("Init").
 *
 *  \subsection sec2_2 Ablaufsteuerung
 *
 *  Hier erfolgt die Beschreibung der eigentlichen Ablaufsteuerung
 *  des Programms ("Loop").
 *
 *  <HR>
 *
 *   \author	RE
 *   \date		01.10.2018
 *   \version 	0.02a             Erste fertige Version
 *   \version 	0.01a             Erste Testversion
 */

/*********************************************************************/
/**
Funktion zur Initialisierung des verwendeten GPIO-Ports

\param   -

\return  -

\version 01.10.2018

\todo universeller, parametrierbarer gestalten
\bug  keine Fehler bekannt
**********************************************************************/
void io_init(void)
{
	LPC_PINCON->PINSEL1 &= ~ (3 << 12);		// P0[22] = GPIO
	LPC_GPIO0->FIODIR |=  1 << 22;			// P0[22] = Ausgang
}

/*********************************************************************/
/**
Funktion zur Erzeugung einer variablen Verzögerungszeit

\param   dtime
		 Diese Variable legt die Verzögerungszeit fest

\return  -

\version 01.10.2018

\todo    -
\bug     keine Fehler bekannt
**********************************************************************/
void delay (uint32_t dtime)
{
	volatile uint32_t i;
 	for (i=0; i < dtime;i++) {}		// Zeitverzögerung
}

/*********************************************************************/
/**
Funktion zum Ein-/Ausschalten der roten LED auf dem Controllerboard

\param   onoff
		 Diese Variable legt fest, ob die rote LED ein- oder
		 ausgeschaltet werden soll.
		 ( 1 : ein, 0 : aus )

\return  -

\version 01.10.2018

\todo    -
\bug     keine Fehler bekannt
**********************************************************************/
void set_led (uint32_t onoff)
{
	if (onoff == 1)
		LPC_GPIO0->FIOSET = 1 << 22;		// P0[22] = High - Pegel
	else
		LPC_GPIO0->FIOCLR = 1 << 22;		// P0[22] = Low - Pegel
}


/*********************************************************************/
/**
 *
 * \brief Dies ist das Hauptprogramm

Dieses Programm läßt die rote LED auf dem Controllerboard blinken.

\param   -

\return  immer 0

\version 01.10.2018

\todo    -
\bug     keine Fehler bekannt
**********************************************************************/
int main(void)
{
	io_init();

	while(1)
	{                    		/** Programmablauf:                  */
		set_led (1);			/** LED einschalten                  */
		delay (DELAYTIME);		/** dann warten                      */
		set_led (0);			/** LED ausschalten                  */
		delay (DELAYTIME);		/** dann wieder warten               */
	}
	return 0 ;
}
